import requests
import json
import os

def save_as_m3u(filename, addresses):
    with open(filename, 'w', encoding='utf-8') as file:
        file.write('#EXTM3U\n')
        for address, title, group_title in addresses:
            file.write(f'#EXTINF:-1 group-title="{group_title}",{title}\n')
            file.write(f'{address}\n')

def main():
    # 主API地址
    main_api_url = "http://api.vipmisss.com:81/xcdsw/json.txt"

    # 获取当前工作目录
    # output_dir = os.path.abspath('.') + '/'
    output_dir = '/home/test/zhibo/'
    try:
        # 发送GET请求获取主API的数据
        response = requests.get(main_api_url)
        if response.status_code == 200:
            try:
                data = json.loads(response.text)
            except json.JSONDecodeError as e:
                print(f"无法解析主API响应的JSON数据：{str(e)}")
                return
        else:
            print(f"无法获取主API数据：{response.status_code}")
            return

        # 创建一个字典来存储不同格式的直播源地址和标题
        sources = {
            'm3u8': [],
            'flv': [],
            'rtmp': [],
            'other': []
        }

        # 获取地址和直播间数量
        for item in data.get("pingtai", []):
            address = item.get("address")
            number = item.get("Number")
            platform_title = item.get("title", "Unknown Platform")

            # 访问具体直播源列表地址
            source_list_url = f"http://api.vipmisss.com:81/mf/{address}"
            source_list_response = requests.get(source_list_url)
            if source_list_response.status_code == 200:
                try:
                    source_data = json.loads(source_list_response.text)
                except json.JSONDecodeError as e:
                    print(f"无法解析直播源列表响应的JSON数据：{str(e)}")
                    continue

                # 获取每个直播源的地址和标题并分类存储
                for source_item in source_data.get("zhubo", []):
                    video_address = source_item.get("address")
                    title = source_item.get("title", "Unknown Title")
                    if '.m3u8' in video_address:
                        sources['m3u8'].append((video_address, title, platform_title))
                    elif '.flv' in video_address:
                        sources['flv'].append((video_address, title, platform_title))
                    elif 'rtmp://' in video_address:
                        sources['rtmp'].append((video_address, title, platform_title))
                    else:
                        sources['other'].append((video_address, title, platform_title))

                print(f"已获取并分类存储 {number} 个直播源地址")

            else:
                print(f"无法获取直播源列表数据：{source_list_response.status_code}")

        # 创建输出目录(如果不存在)
        os.makedirs(output_dir, exist_ok=True)

        # 将分类后的直播源地址分别写入不同的 .m3u 文件
        for format_type, addresses in sources.items():
            if addresses:
                file_path = f'{output_dir}{format_type}_playlist_old.m3u'
                save_as_m3u(file_path, addresses)
                print(f"文件已保存: {file_path}")

        print("所有直播源地址已成功写入 .m3u 文件")

    except Exception as e:
        print(f"发生异常：{str(e)}")

if __name__ == "__main__":
    main()
